==> ultraman-bocp-gen-codegen-0.0.18-sources.jar: com/xforceplus/ultraman/bocp/gen/config/BocpConstVal.java <==
package com.xforceplus.ultraman.bocp.gen.config;


import java.nio.charset.StandardCharsets;

public interface BocpConstVal {
    String BO = "BO";
    String PROJECT = "Project";
    String APPLICATION = "Application";
    String APPLICATION_CLIENT = "ApplicationClinet";
    String APPLICATION_SERVICE = "ApplicationService";
    String APPLICATION_SERVICE_PACKAGE = "ApplicationServicePackage";

    //app模板信息
    String TEMPLATE_GITIGNORE = "/templates/application/.gitignore";
    String TEMPLATE_GITLAB_CI_YML = "/templates/application/.gitlab-ci.yml";
    String TEMPLATE_APPLICATION_YML = "/templates/application/application.yml";
    String TEMPLATE_CLIENT_POM_XML = "/templates/application/client-pom.xml";
    String TEMPLATE_POM_XML = "/templates/application/pom.xml";
    String TEMPLATE_PARENT_POM_XML = "/templates/application/parent-pom.xml";
    String TEMPLATE_SERVICE_POM_XML = "/templates/application/service-pom.xml";
    String TEMPLATE_SERVICEAPPLICATION_JAVA = "/templates/application/ServiceApplication.java";
    String TEMPLATE_SERVICEAPPLICATIONTESTS_JAVA = "/templates/application/ServiceApplicationTests.java";
    //app
    String GITIGNORE = "appGitignore";
    String GITLAB = "appGitlab";
    String APPLICATION_YML = "appApplicationYml";
    String CLIENT_POM = "appClientPom";
    String POM = "appPom";
    String PARENT_POM = "appParentPom";
    String SERVICE_POM = "appServicePom";
    String SERVICE_APPLICATION = "appApplicationService";
    String SERVICE_APPLICATION_TESTS = "appApplicationTests";

    String GITIGNORE_PATH = "gitignore_path";
    String GITLAB_PATH = "gitlab_path";
    String APPLICATION_YML_PATH = "application_yml_path";
    String CLIENT_POM_PATH = "client_pom_path";
    String PARENT_POM_PATH = "parent_pom_path";
    String POM_PATH = "pom_path";
    String SERVICE_POM_PATH = "service_pom_path";
    String SERVICE_APPLICATION_PATH = "service_application_path";
    String SERVICE_APPLICATION_TESTS_PATH = "service_application_test_path";


    //模块模板信息
    String MODULE = "Module";
    String MODULE_CLIENT = "ModuleClient";
    String MODULE_SERVICE = "ModuleService";
    String MODULE_DOMAIN = "ModuleDomain";
    String MODULE_SERVICE_PACKAGE = "ModuleServicePackage";

    String TEMPLATE_MODULE_GITIGNORE = "/templates/module/.gitignore";
    String TEMPLATE_MODULE_GITLAB_CI_YML = "/templates/module/.gitlab-ci.yml";
    String TEMPLATE_MODULE_YML = "/templates/module/application.yml";
    String TEMPLATE_MODULE_CLIENT_POM_XML = "/templates/module/client-pom.xml";
    String TEMPLATE_MODULE_PARENT_POM_XML = "/templates/module/parent-pom.xml";
    String TEMPLATE_MODULE_DOMAIN_POM_XML = "/templates/module/domain-pom.xml";
    String TEMPLATE_MODULE_POM_XML = "/templates/module/pom.xml";
    String TEMPLATE_MODULE_SERVICE_POM_XML = "/templates/module/service-pom.xml";
    String TEMPLATE_MODULE_SERVICEAPPLICATION_JAVA = "/templates/module/ServiceApplication.java";
    String TEMPLATE_MODULE_SERVICEAPPLICATIONTESTS_JAVA = "/templates/module/ServiceApplicationTests.java";
    //module
    String MODULE_GITIGNORE = "moduleGitignore";
    String MODULE_GITLAB = "moduleGitlab";
    String MODULE_APPLICATION_YML = "moduleApplicationYml";
    String MODULE_CLIENT_POM = "moduleClientPom";
    String MODULE_PARENT_POM = "moduleParentPom";
    String MODULE_DOMAIN_POM = "moduleDomainPom";
    String MODULE_POM = "modulePom";
    String MODULE_SERVICE_POM = "moduleServicePom";
    String MODULE_SERVICE_APPLICATION = "moduleApplicationService";
    String MODULE_SERVICE_APPLICATION_TESTS = "moduleApplicationTests";

    String MODULE_GITIGNORE_PATH = "module_gitignore_path";
    String MODULE_GITLAB_PATH = "module_gitlab_path";
    String MODULE_APPLICATION_YML_PATH = "module_application_yml_path";
    String MODULE_CLIENT_POM_PATH = "module_client_pom_path";
    String MODULE_PARENT_POM_PATH = "module_parent_pom_path";
    String MODULE_DOMAIN_POM_PATH = "module_domain_pom_path";
    String MODULE_POM_PATH = "module_pom_path";
    String MODULE_SERVICE_POM_PATH = "module_service_pom_path";
    String MODULE_SERVICE_APPLICATION_PATH = "module_service_application_path";
    String MODULE_SERVICE_APPLICATION_TESTS_PATH = "module_service_application_test_path";


    //业务对象模板信息
    String TEMPLATE_ENTITY_JAVA = "/templates/bo/Entity.java";
    String TEMPLATE_ENTITY_KT = "/templates/bo/Entity.kt";
    String TEMPLATE_MAPPER = "/templates/bo/Mapper.java";
    String TEMPLATE_XML = "/templates/bo/Mapper.xml";
    String TEMPLATE_SERVICE = "/templates/bo/Service.java";
    String TEMPLATE_SERVICE_IMPL = "/templates/bo/ServiceImpl.java";
    String TEMPLATE_CONTROLLER = "/templates/bo/Controller.java";
    String TEMPLATE_FEIGN = "/templates/bo/ClientFeignApi.java";

    String ENTITY_PACKEGE = "EntityPackege";
    String SERVICE_PACKEGE = "ServicePackege";
    String SERVICE_IMPL_PACKEGE = "ServiceImplPackege";
    String MAPPER_PACKEGE = "MapperPackege";
    String XML_PACKEGE = "XmlPackege";
    String CONTROLLER_PACKEGE = "ControllerPackege";
    String FEIGN_PACKEGE = "FeignPackege";

    //DTO模板信息
    String TEMPLATE_DTO_JAVA = "/templates/dto/Dto.java";
    String TEMPLATE_DTO_KT = "/templates/dto/Dto.kt";
    String DTO_PACKAGE = "DtoPackage";

    String FEIGN = "Feign";
    String FEIGN_PATH = "feign_path";

    //引擎类型
    String BOENGINE = "bo";
    String APPLICATIONENGINE = "app";
    String MODULEENGINE = "mo";
    String WEBENGINE = "web";
    String DICTENGINE = "dict";
    String DTOENGINE = "dto";

    //后缀信息
    String YML_SUFFIX = ".yml";
    String PROPERTIES_SUFFIX = ".properties";
    String CLIENT_SUFFIX = "-client";
    String SERVICE_SUFFIX = "-service";
    String DOMAIN_SUFFIX = "-domain";

    //固定路径信息
    String JAVA_SRC_PATH = "src.main.java";
    String RESOURCES_SRC_PATH = "src.main.resources";

    String JAVA_TMPDIR = "java.io.tmpdir";
    String UTF8 = StandardCharsets.UTF_8.name();
    String UNDERLINE = "_";

    //基类模板
    String TEMPLATE_BASE_ENTITY_JAVA = "/templates/bo/BaseEntity.java";
    String TEMPLATE_BASE_ENTITY_KT = "/templates/bo/BaseEntity.kt";

    //字典模板信息
    String TEMPLATE_ENUM_JAVA = "/templates/dict/Enum.java";
    String TEMPLATE_ENUM_KT = "/templates/dict/Enum.kt";
    String DICT_PACKAGE = "DictPackage";

    //DTO信息
    String DTO_PATH = "dto_path";
    String DTO = "Dto";
}

==> ultraman-bocp-gen-codegen-0.0.38-sources.jar: com/xforceplus/ultraman/bocp/gen/config/BocpConstVal.java <==
package com.xforceplus.ultraman.bocp.gen.config;


import java.nio.charset.StandardCharsets;

public interface BocpConstVal {
    String BO = "BO";
    String PROJECT = "Project";
    String APPLICATION = "Application";
    String APPLICATION_CLIENT = "ApplicationClinet";
    String APPLICATION_SERVICE = "ApplicationService";
    String APPLICATION_SERVICE_PACKAGE = "ApplicationServicePackage";

    //app模板信息
    String TEMPLATE_GITIGNORE = "/templates/application/.gitignore";
    String TEMPLATE_GITLAB_CI_YML = "/templates/application/.gitlab-ci.yml";
    String TEMPLATE_APPLICATION_YML = "/templates/application/application.yml";
    String TEMPLATE_CLIENT_POM_XML = "/templates/application/client-pom.xml";
    String TEMPLATE_POM_XML = "/templates/application/pom.xml";
    String TEMPLATE_PARENT_POM_XML = "/templates/application/parent-pom.xml";
    String TEMPLATE_SERVICE_POM_XML = "/templates/application/service-pom.xml";
    String TEMPLATE_SERVICEAPPLICATION_JAVA = "/templates/application/ServiceApplication.java";
    String TEMPLATE_SERVICEAPPLICATIONTESTS_JAVA = "/templates/application/ServiceApplicationTests.java";
    //app
    String GITIGNORE = "appGitignore";
    String GITLAB = "appGitlab";
    String APPLICATION_YML = "appApplicationYml";
    String CLIENT_POM = "appClientPom";
    String POM = "appPom";
    String PARENT_POM = "appParentPom";
    String SERVICE_POM = "appServicePom";
    String SERVICE_APPLICATION = "appApplicationService";
    String SERVICE_APPLICATION_TESTS = "appApplicationTests";

    String GITIGNORE_PATH = "gitignore_path";
    String GITLAB_PATH = "gitlab_path";
    String APPLICATION_YML_PATH = "application_yml_path";
    String CLIENT_POM_PATH = "client_pom_path";
    String PARENT_POM_PATH = "parent_pom_path";
    String POM_PATH = "pom_path";
    String SERVICE_POM_PATH = "service_pom_path";
    String SERVICE_APPLICATION_PATH = "service_application_path";
    String SERVICE_APPLICATION_TESTS_PATH = "service_application_test_path";


    //模块模板信息
    String MODULE = "Module";
    String MODULE_CLIENT = "ModuleClient";
    String MODULE_SERVICE = "ModuleService";
    String MODULE_DOMAIN = "ModuleDomain";
    String MODULE_SERVICE_PACKAGE = "ModuleServicePackage";

    String TEMPLATE_MODULE_GITIGNORE = "/templates/module/.gitignore";
    String TEMPLATE_MODULE_GITLAB_CI_YML = "/templates/module/.gitlab-ci.yml";
    String TEMPLATE_MODULE_YML = "/templates/module/application.yml";
    String TEMPLATE_MODULE_CLIENT_POM_XML = "/templates/module/client-pom.xml";
    String TEMPLATE_MODULE_PARENT_POM_XML = "/templates/module/parent-pom.xml";
    String TEMPLATE_MODULE_DOMAIN_POM_XML = "/templates/module/domain-pom.xml";
    String TEMPLATE_MODULE_POM_XML = "/templates/module/pom.xml";
    String TEMPLATE_MODULE_SERVICE_POM_XML = "/templates/module/service-pom.xml";
    String TEMPLATE_MODULE_SERVICEAPPLICATION_JAVA = "/templates/module/ServiceApplication.java";
    String TEMPLATE_MODULE_SERVICEAPPLICATIONTESTS_JAVA = "/templates/module/ServiceApplicationTests.java";
    //module
    String MODULE_GITIGNORE = "moduleGitignore";
    String MODULE_GITLAB = "moduleGitlab";
    String MODULE_APPLICATION_YML = "moduleApplicationYml";
    String MODULE_CLIENT_POM = "moduleClientPom";
    String MODULE_PARENT_POM = "moduleParentPom";
    String MODULE_DOMAIN_POM = "moduleDomainPom";
    String MODULE_POM = "modulePom";
    String MODULE_SERVICE_POM = "moduleServicePom";
    String MODULE_SERVICE_APPLICATION = "moduleApplicationService";
    String MODULE_SERVICE_APPLICATION_TESTS = "moduleApplicationTests";

    String MODULE_GITIGNORE_PATH = "module_gitignore_path";
    String MODULE_GITLAB_PATH = "module_gitlab_path";
    String MODULE_APPLICATION_YML_PATH = "module_application_yml_path";
    String MODULE_CLIENT_POM_PATH = "module_client_pom_path";
    String MODULE_PARENT_POM_PATH = "module_parent_pom_path";
    String MODULE_DOMAIN_POM_PATH = "module_domain_pom_path";
    String MODULE_POM_PATH = "module_pom_path";
    String MODULE_SERVICE_POM_PATH = "module_service_pom_path";
    String MODULE_SERVICE_APPLICATION_PATH = "module_service_application_path";
    String MODULE_SERVICE_APPLICATION_TESTS_PATH = "module_service_application_test_path";


    //业务对象模板信息
    String TEMPLATE_ENTITY_JAVA = "/templates/bo/Entity.java";
    String TEMPLATE_ENTITY_KT = "/templates/bo/Entity.kt";
    String TEMPLATE_MAPPER = "/templates/bo/Mapper.java";
    String TEMPLATE_XML = "/templates/bo/Mapper.xml";
    String TEMPLATE_SERVICE = "/templates/bo/Service.java";
    String TEMPLATE_SERVICE_IMPL = "/templates/bo/ServiceImpl.java";
    String TEMPLATE_CONTROLLER = "/templates/bo/Controller.java";
    String TEMPLATE_FEIGN = "/templates/bo/ClientFeignApi.java";

    //组合业务对象模板信息
    String TEMPLATE_COMBO_ENTITY_JAVA = "/templates/bo/ComboEntity.java";
    String TEMPLATE_COMBO_ENTITY_KT = "/templates/bo/ComboEntity.kt";

    String ENTITY_PACKEGE = "EntityPackege";
    String SERVICE_PACKEGE = "ServicePackege";
    String SERVICE_IMPL_PACKEGE = "ServiceImplPackege";
    String MAPPER_PACKEGE = "MapperPackege";
    String XML_PACKEGE = "XmlPackege";
    String CONTROLLER_PACKEGE = "ControllerPackege";
    String FEIGN_PACKEGE = "FeignPackege";

    //DTO模板信息
    String TEMPLATE_DTO_JAVA = "/templates/dto/Dto.java";
    String TEMPLATE_DTO_KT = "/templates/dto/Dto.kt";
    String DTO_PACKAGE = "DtoPackage";

    String FEIGN = "Feign";
    String FEIGN_PATH = "feign_path";

    //引擎类型
    String BOENGINE = "bo";
    String APPLICATIONENGINE = "app";
    String MODULEENGINE = "mo";
    String WEBENGINE = "web";
    String DICTENGINE = "dict";
    String DTOENGINE = "dto";

    //后缀信息
    String YML_SUFFIX = ".yml";
    String PROPERTIES_SUFFIX = ".properties";
    String CLIENT_SUFFIX = "-client";
    String SERVICE_SUFFIX = "-service";
    String DOMAIN_SUFFIX = "-domain";

    //固定路径信息
    String JAVA_SRC_PATH = "src.main.java";
    String RESOURCES_SRC_PATH = "src.main.resources";

    String JAVA_TMPDIR = "java.io.tmpdir";
    String UTF8 = StandardCharsets.UTF_8.name();
    String UNDERLINE = "_";

    //基类模板
    String TEMPLATE_BASE_ENTITY_JAVA = "/templates/bo/BaseEntity.java";
    String TEMPLATE_BASE_ENTITY_KT = "/templates/bo/BaseEntity.kt";

    //字典模板信息
    String TEMPLATE_ENUM_JAVA = "/templates/dict/Enum.java";
    String TEMPLATE_ENUM_KT = "/templates/dict/Enum.kt";
    String DICT_PACKAGE = "DictPackage";

    //DTO信息
    String DTO_PATH = "dto_path";
    String DTO = "Dto";

    //元数据信息
    String ENTITY_META = "EntityMeta";
    String ENTITY_META_PATH = "entity_meta_path";
    String ENTITY_META_PACKAGE = "EntityMetaPackage";
    String TEMPLATE_ENTITY_META_JAVA = "/templates/bo/EntityMeta.java";
    String TEMPLATE_ENTITY_META_KT = "/templates/bo/EntityMeta.kt";
}
